# mempw

## Description
Memorable password generator in Python

## Installation
Github:
```bash
git clone https://github.com/mdvthu/mempw
pip3 install ./mempw
```
PyPI:
```bash
pip3 install mempw
```

## Configuration
Edit `mempw/config.py` to customise settings

## Wordlist
Uses system (Linux/Unix) wordlists by default.
Default search locations are specified in the configuration.

## Usage
Python package installs a Linux command line interface,
available through the command `mempw`
